#!/usr/bin/env python3
from setuptools import setup, find_packages


def read_requirements(filename):
    return [req.strip() for req in open(filename)]


requirements = read_requirements('requirements.txt')
dev_requirements = read_requirements('requirements-dev.txt')

setup(
    name='website_generator',
    version=open('VERSION').read().strip(),
    author='Lucidiot',
    packages=find_packages(
        exclude=["*.tests", "*.tests.*", "tests.*", "tests"],
    ),
    entry_points={
        'console_scripts': [
            'website_generator=website_generator.__main__:main',
        ],
    },
    package_data={
        '': ['*.md', 'LICENSE', 'README'],
    },
    python_requires='>=3.5',
    install_requires=requirements,
    extras_require={
        'dev': dev_requirements,
    },
    tests_require=dev_requirements,
    license='GNU General Public License 3',
    description="Static site generator inspired by Ansible",
    long_description=open('README.rst').read(),
    long_description_content_type='text/x-rst',
    keywords="static site generator http gopher web html jinja2",
    url="https://gitlab.com/Lucidiot/website_generator",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Intended Audience :: Information Technology",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Topic :: Software Development :: Build Tools",
        "Topic :: Internet",
    ],
    project_urls={
        "Source Code": "https://gitlab.com/Lucidiot/website_generator",
        "GitHub Mirror": "https://github.com/Lucidiot/website_generator",
    }
)
